# Essential JS 2 - Modern JavaScript UI Components 
The only JavaScript UI package you will ever need.

[![Screens of showcase applications](https://ej2.syncfusion.com/products/ej2-banner.gif)](https://syncfusion.com/products/javascript/)

*Screens of [showcase applications](#showcase-applications) created using Essential JS 2*

## Table of Contents
* [Framework highlights](#framework-highlights)
* [Control list](#control-list)
* [Resources](#resources)
* [Supported Frameworks](#supported-frameworks)
* [Showcase Applications](#showcase-applications)
* [Release Notes](#release-notes)
* [License](#license)

## Framework highlights

### Lightweight and user friendly
The entire Essential JS 2 framework is built from scratch to be lightweight and modular. Its footprint can be reduced further by including only the specific components and features your application requires.

### Modular architecture
All components have been built as modules to enable selective referencing, so only the components and features you need are included in your application.

### Built for performance
Performance is critical for delivering a good user experience. We ensure that all our components are designed and built to achieve the best performance possible.

### Responsive and touch friendly
All Essential JS 2 controls are touch friendly and render adaptively based on the device they are on to provide optimal usage experience on phones, tablets and desktops.

### Stunning built-in themes
Pixel-perfect built-in themes are available in material, bootstrap and fabric design. In addition, it comes with Accessible high-contrast theme and an online tool "[Theme Studio](https://ej2.syncfusion.com/themestudio/)" to customize the provided built-in themes.

### Globalization simplified
Easily build applications to be used by a global audience in various language and culture settings.

### Stay current
With our commitment to at least four major updates per year, you receive the most up-to-date functionality and new components in addition to monthly service packs and bug fixes. Custom patches are available as needed.


## Control List
* Grids
    * [**Data Grid**](https://syncfusion.com/products/javascript/data-grid) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/grid/gridoverview.html)
    * [**Pivot Grid**](https://www.syncfusion.com/products/javascript/pivot-grid) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/pivotview/default.html) 
* Data Visualization
    * [**Chart**](https://www.syncfusion.com/products/javascript/chart) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/chart/line.html)
    * [Circular Gauge](https://www.syncfusion.com/products/javascript/circulargauge) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/circulargauge/default.html)
    * [**Diagram**](https://www.syncfusion.com/products/javascript/diagram) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/diagram/default-functionalities.html)
    * [Heat Map](https://www.syncfusion.com/products/javascript/heatmap) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/heatmap/default.html)
    * [Linear Gauge](https://www.syncfusion.com/products/javascript/lineargauge) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/lineargauge/default.html)
    * [Maps](https://www.syncfusion.com/products/javascript/maps) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/maps/default.html)
    * [RangeNavigator](https://www.syncfusion.com/products/javascript/rangenavigator) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/rangenavigator/default.html)
    * [Smith Chart](https://www.syncfusion.com/products/javascript/smithchart) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/smithchart/default.html)
    * [Sparkline](https://www.syncfusion.com/products/javascript/sparkline) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/sparkline/default.html)
    * [TreeMap](https://www.syncfusion.com/products/javascript/treemap) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/treemap/default.html)
* Calendar
    * [**Schedule**](https://www.syncfusion.com/products/javascript/schedule) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/schedule/default.html)
    * [Calendar](https://www.syncfusion.com/products/javascript/calendar) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/calendar/default.html)
    * [Date Picker](https://www.syncfusion.com/products/javascript/datepicker) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/datepicker/default.html)
    * [Date-Range Picker](https://www.syncfusion.com/products/javascript/daterangepicker) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/daterangepicker/default.html)
    * [Date-Time Picker](https://www.syncfusion.com/products/javascript/datetimepicker) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/datetimepicker/default.html)
    * [Time Picker](https://www.syncfusion.com/products/javascript/timepicker) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/timepicker/default.html)
* Editors
    * [Autocomplete](https://www.syncfusion.com/products/javascript/autocomplete) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/autocomplete/default.html)
    * [Check Box](https://www.syncfusion.com/products/javascript/checkbox) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/check-box.html)
    * [Color Picker](https://www.syncfusion.com/products/javascript/color-picker) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/colorpicker/default.html)
    * [Combo Box](https://www.syncfusion.com/products/javascript/combobox) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/combobox/default.html)
    * [**Document Editor**](https://www.syncfusion.com/products/javascript/document-editor) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/documenteditor/default.html)
    * [**Dropdown List**](https://www.syncfusion.com/products/javascript/dropdownlist) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/dropdownlist/default.html)
    * [Form Validator](https://www.syncfusion.com/products/javascript/form-validator) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/form-validator/default.html)
    * [Radio Button](https://www.syncfusion.com/products/javascript/radio-button) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/radio-button.html)
    * [**Rich Text Editor**](https://www.syncfusion.com/products/javascript/rich-text-editor) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/rte/rich-text-editor-tools.htmll)
    * [Masked Text Box](https://www.syncfusion.com/products/javascript/maskedtextbox) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/maskedtextbox/default.html)
    * [Multiselect Dropdown](https://www.syncfusion.com/products/javascript/multiselect) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/multiselect/default.html)
    * [Numeric Textbox](https://www.syncfusion.com/products/javascript/numerictextbox) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/numerictextbox/default.html)
    * [Slider](https://www.syncfusion.com/products/javascript/slider) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/slider/default.html)
    * [Switch](https://www.syncfusion.com/products/javascript/switch) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/switch.html)
    * [Textbox](https://www.syncfusion.com/products/javascript/text-box) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/textbox/default.html)
    * [Uploader](https://www.syncfusion.com/products/javascript/uploader) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/uploader/default.html)
* Buttons
    * [Button](https://www.syncfusion.com/products/javascript/button) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/default.html)
    * [Button Group](https://www.syncfusion.com/products/javascript/button-group) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/button-group.html)
    * [Dropdown Button](https://www.syncfusion.com/products/javascript/dropdown-button) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/drop-down-button.html)
    * [Split Button](https://www.syncfusion.com/products/javascript/split-button) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/button/split-button.html)
* Layout
    * [Avatar](https://www.syncfusion.com/products/javascript/avatar) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/avatar/default.html)
    * [Card](https://www.syncfusion.com/products/javascript/card) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/card/basic.html)
    * [Dialog](https://www.syncfusion.com/products/javascript/dialog) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/dialog/default.html)
    * [**List View**](https://www.syncfusion.com/products/javascript/listview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/listview/default.html)
* Navigation
    * [Accordion](https://www.syncfusion.com/products/javascript/accordion) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/accordion/default.html)
    * [**Context Menu**](https://www.syncfusion.com/products/javascript/context-menu) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/context-menu/context-menu.html)
    * [Sidebar](https://www.syncfusion.com/products/javascript/sidebar) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/sidebar/default)
    * [Tab](https://www.syncfusion.com/products/javascript/tab) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/tab/default.html)
    * [Toolbar](https://www.syncfusion.com/products/javascript/toolbar) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/toolbar/default.html)
    * [**Tree View**](https://www.syncfusion.com/products/javascript/tree-view) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/treeview/default.html)
* Notification
    * [Badge](https://www.syncfusion.com/products/javascript/badge) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/badge/default.html)
    * [Toast](https://www.syncfusion.com/products/javascript/toast) (Preview) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/toast/default.html)
    * [Tooltip](https://www.syncfusion.com/products/javascript/tooltip) - [*Live demo*](https://ej2.syncfusion.com/demos#/material/tooltip/default.html)

## Supported Frameworks
* [Angular](https://www.syncfusion.com/products/angular)
* [React](https://www.syncfusion.com/products/react)
* [Vue.js](https://www.syncfusion.com/products/vue)
* [ASP.NET Core](https://www.syncfusion.com/products/aspnetcore)
* [ASP.NET MVC](https://www.syncfusion.com/products/aspnetmvc)

## Resources
* [Documentation](https://ej2.syncfusion.com/documentation/?lang=typescript)
* [Theme Studio](https://ej2.syncfusion.com/themestudio/)
* [Custom Resource Generator](https://crg.syncfusion.com/)
* [Contact Support](https://www.syncfusion.com/support/directtrac/incidents/newincident)
* [Forums](https://www.syncfusion.com/forums/essential-js2)
* [What's New](https://www.syncfusion.com/products/whatsnew/essential-js2)
* [Road Map](https://www.syncfusion.com/products/roadmap/essential-js2)
* [E-Books](https://www.syncfusion.com/ebooks?tag=javascript)

## Showcase Applications
* [Diagram Builder](https://ej2.syncfusion.com/showcase/angular/diagrambuilder/)
* [Story Estimator](https://aspdotnetcore.syncfusion.com/showcase/aspnetcore/story-estimator/)
* [Stock Chart](https://ej2.syncfusion.com/showcase/angular/stockchart)
* [IT Asset Management](https://ej2.syncfusion.com/showcase/vue/assetmanagement/)
* [Expense Tracker](https://ej2.syncfusion.com/showcase/typescript/expensetracker/)
* [Web Mail](https://ej2.syncfusion.com/showcase/typescript/webmail/)
* [Loan Calculator](https://ej2.syncfusion.com/showcase/typescript/loancalculator/)


## Release Notes
Please refer this [link](https://ej2.syncfusion.com/documentation/release-notes/?lang=typescript)

## License
This is a commercial product and requires a paid license for possession or use. Syncfusion’s licensed software, including this component, is subject to the terms and conditions of Syncfusion's EULA (https://www.syncfusion.com/eula/es/). To acquire a license, you can purchase one at https://www.syncfusion.com/sales/products or start a free 30-day trial here (https://www.syncfusion.com/account/manage-trials/start-trials).

A free community license (https://www.syncfusion.com/products/communitylicense) is also available for companies and individuals whose organizations have less than $1 million USD in annual gross revenue and five or fewer developers.


    © Copyright 2018 Syncfusion, Inc. All Rights Reserved. 
    The Syncfusion Essential Studio license and copyright applies to this distribution.
